@@ -47,8 +47,6 @@ DesktopWidget::DesktopWidget(QWidget *parent, QString appletId, bool debug) :
     XChangeProperty(QX11Info::display(), winId(), winTypeAtom, XA_ATOM, 32,
             PropModeReplace, (unsigned char *) &homeAppletAtom, 1);
 
-    //setAttribute(Qt::WA_Maemo5NonComposited, true);
-
     if (!appletId.isEmpty())
         m_AppletId = appletId;
     else
@@ -70,8 +68,8 @@ DesktopWidget::DesktopWidget(QWidget *parent, QString appletId, bool debug) :
                                          "status_changed", this, SLOT(netStateChanged(QString,QString,QString,QString)));
 
     //Connect to display state change:
-    //QDBusConnection::systemBus().connect(QString(), MCE_SIGNAL_PATH, MCE_SIGNAL_IF,
-    //                                     MCE_DISPLAY_SIG, this, SLOT(displayStateChanged(QString)));
+    QDBusConnection::systemBus().connect(QString(), MCE_SIGNAL_PATH, MCE_SIGNAL_IF,
+                                         MCE_DISPLAY_SIG, this, SLOT(displayStateChanged(QString)));
 
     m_UpdateTimer = NULL;
     m_Updating = false;
@@ -124,8 +122,8 @@ DesktopWidget::~DesktopWidget()
     QDBusConnection::systemBus().disconnect("com.nokia.icd", "/com/nokia/icd", "com.nokia.icd",
                                             "status_changed", this, SLOT(netStateChanged(QString,QString,QString,QString)));
 
-    /*QDBusConnection::systemBus().disconnect(QString(), MCE_SIGNAL_PATH, MCE_SIGNAL_IF,
-                                            MCE_DISPLAY_SIG, this, SLOT(displayStateChanged(QString)));*/
+    QDBusConnection::systemBus().disconnect(QString(), MCE_SIGNAL_PATH, MCE_SIGNAL_IF,
+                                            MCE_DISPLAY_SIG, this, SLOT(displayStateChanged(QString)));
 
     if (m_WaitIcon != NULL)
         delete m_WaitIcon;
@@ -403,18 +401,16 @@ bool DesktopWidget::UpdateData()
     return true;
 }
 
-/*
 void DesktopWidget::displayStateChanged(QString displayState)
 {
+    //When the screen is off hide the widget. The progressbar seems to be cpu "heavy", don't know why,
+    //so it is better to avoid drawing it when not necessary
     if (displayState == QLatin1String(MCE_DISPLAY_OFF_STRING)) {
-        if (m_UpdateTimer)
-            m_UpdateTimer->stop();
+        this->setVisible(false);
     }else if (displayState == QLatin1String(MCE_DISPLAY_ON_STRING)) {
-        if (m_UpdateTimer)
-            CreateTimer();
+        this->setVisible(true);
     }
 }
-*/
 
 void DesktopWidget::netStateChanged(QString, QString type, QString state, QString)
 {
